# PyRecognition 0.1v

**PySpeech** é um modulo que busca trazer um reconhecimento de
voz de qualidade para o python.

## Funções

* `PyRecognition.recognition(language)` - Recebe valor string com a linguagem que será utilizada. (Até o momento: 'pt-BR', 'en-US').
Retorna o que foi reconhecido pelo sistema.

### Necessario

**-Selenium**
**-Google Chrome 87+**

